import '@zhinjs/plugin-prompt';
import '@zhinjs/plugin-database';
import '@zhinjs/plugin-http';
import { TableDecl } from '@zhinjs/plugin-database';
import { Bot, Dict } from 'zhin';
import { Method } from 'axios';
import { GroupMessageEvent } from 'icqq/';
import { EventPayloadMap, Repository, WebhookEventName } from '@octokit/webhooks-types/schema';
export namespace GithubTable {
    interface Types {
        name: string;
        secret: string;
    }
    const model: TableDecl;
}
export type ReplyPayloads = {
    [K in keyof ReplyHandler]?: ReplyHandler[K] extends (...args: infer P) => any ? P : never;
};
declare module '@zhinjs/plugin-database' {
    namespace UserTable {
        interface Types {
            github_accessToken: string;
            github_refreshToken: string;
        }
    }
    namespace GroupTable {
        interface Types {
            github_webhooks: Dict<EventConfig>;
        }
    }
}
export type EventData<T = {}> = [string, (ReplyPayloads & T)?];
export interface OAuth {
    access_token: string;
    expires_in: string;
    refresh_token: string;
    refresh_token_expires_in: string;
    token_type: string;
    scope: string;
}
export class GitHub {
    bot: Bot;
    config: Config;
    history: Dict<ReplyPayloads>;
    private http;
    constructor(bot: Bot, config: Config);
    getTokens(params: any): Promise<OAuth>;
    private _request;
    authorize(event: GroupMessageEvent, message: string): Promise<void>;
    request(method: Method, url: string, event: Bot.MessageEvent, body?: any, headers?: Dict): Promise<any>;
}
export interface Config {
    path?: string;
    appId?: string;
    appSecret?: string;
    messagePrefix?: string;
    redirect?: string;
    promptTimeout?: number;
    replyTimeout?: number;
    requestTimeout?: number;
}
export class ReplyHandler {
    github: GitHub;
    botEvent: Bot.MessageEvent;
    content?: string;
    constructor(github: GitHub, botEvent: Bot.MessageEvent, content?: string);
    request(method: Method, url: string, message: string, body?: any, headers?: Dict): Promise<string>;
    link(url: string): string;
    react(url: string): Promise<string>;
    transform(source: string): Promise<any>;
    reply(url: string, params?: Dict): Promise<string>;
    base(url: string): Promise<string>;
    merge(url: string, method?: 'merge' | 'squash' | 'rebase'): Promise<string>;
    rebase(url: string): Promise<string>;
    squash(url: string): Promise<string>;
    close(url: string, commentUrl: string): Promise<void>;
}
declare module 'marked' {
    namespace Tokens {
        interface Def {
            type: 'def';
        }
        interface Paragraph {
            tokens: marked.Token[];
        }
    }
}
export function transform(source: string): any;
type Camelize<S extends string> = S extends `${infer L}_${infer M}${infer R}` ? `${L}${Uppercase<M>}${Camelize<R>}` : S;
type ActionName<E extends WebhookEventName> = EventPayloadMap[E] extends {
    action: infer A;
} ? A & string : never;
export type EventConfig = {
    [E in WebhookEventName as Camelize<E>]?: EventPayloadMap[E] extends {
        action: infer A;
    } ? boolean | {
        [K in A & string as Camelize<K>]?: boolean;
    } : boolean;
};
type EmitterWebhookEventName = WebhookEventName | keyof {
    [E in WebhookEventName as E | `${E}/${ActionName<E>}`]: any;
};
export interface CommonPayload {
    action?: string;
    repository?: Repository;
}
type Payload<T extends EmitterWebhookEventName> = T extends `${infer E}/${infer A}` ? EventPayloadMap[E & WebhookEventName] & {
    action: A;
} : EventPayloadMap[T & WebhookEventName];
export const defaultEvents: EventConfig;
type EventHandler<T extends EmitterWebhookEventName, P = {}> = (payload: Payload<T>) => EventData<P>;
export function addListeners(on: <T extends EmitterWebhookEventName>(event: T, handler: EventHandler<T>) => void): void;
declare module 'zhin' {
    namespace Bot {
        interface Services {
            github: GitHub;
        }
    }
}
export const name = "github";
export const using: string[];
export function install(bot: Bot, config: Config): void;
